/* -----------------------------------------------------------------------------
reg_core_nan_01.H - Registers, address definitions of
	"MOTION CONTROLLER MODULE" 00000-4000-000-00 for 
  Eight Axes Controller-Driver Application Board
	  P/N:00100-4000-000-01 (NAN Instruments Ltd.)

	In the Moton Control Module ther is 'APEC' PLD EP1K30FC256-3	
	This Registers is operated with:
		-- External Bank 1
		-- Number of Wait States = 1
		-- Wait State Mode = 1 (Internal wait state only)

	with out INTERRUPTS:
		IRQ1 -- inver. of RFS signal ( start frame) (OPTION)
		IRQ2 -- Alarm Interrupt. Edge-sensitive high to low (OPTION)

Correction:
15/10/03: PIO Interface of the E-710 Digital Piezo Controller
file: nan_01.etf
----------------------------------------------------------------------------- */
#define flash_offset 0x600000	/* _int addr. after Flash Memory Size (AM29LV800BT) */

/*----- System Control Register, recogn. in FLEX -- write function--------*/

#define flx_syscon flash_offset + 0x00	// _short

// Write Function
// 0 -- OE_GENERAL;    1 - enable user output		
// 1 -- GREEN_LED_1;   0 - enable led, 1 - desable led	
// 2 -- GREEN_LED_2;   0 - enable led, 1 - desable led	
// 3 -- EN_SDATA_OUT;(Option)  1 - Enable SDATA_OUT, 0 - SDATA_OUT is '0'
// 4 -- GEN_ALARM;(Option)     1 - ALARM_OUT=1, 0 - ALARM_OUT=0;
// 5 -- EN_ALARM;(Option)      1 - Enable ALARM_IN to ALARM_OUT, 0 - Disable function 

// Read Function
// 0 -- OE_GENERAL;    1 - enable user output		
// 1 -- GREEN_LED_1;   0 - enable led, 1 - desable led; J1/A56 -- D4/4	
// 2 -- YELLOW_LED_2;   0 - enable led, 1 - desable led; J2/A47 -- D4/2
// 3 -- EN_SDATA_OUT;(Option)
// 4 -- GEN_ALARM;(Option)
// 5 -- EN_ALARM;(Option)
// 6 -- NC
// 7 -- NC
// 8 -- ALARM_IN;(Option)	recognize -- P2/2,7
// 9 -- Extract_Frame;(Option) 1 -- Frame is extract
//10 -- NC
//11 -- ID_0=0(permanent)
//12 -- ID_1=0(permanent)
//13 -- ID_2=0(permanent)
//14 -- ID_3=0(permanent)
//15 -- ID_4=0(permanent)

/*------ NOT AVALIABLE Setup Extract Frame of Link Interface --------------------------*/
//#define setup_frame_link flash_offset + 0x01	// _short (not avaliable)
// only Write Command
// write operation is setup H/W link interface to receive new frame


/*----- Time Sichronizated Register ---------------------------------------------------*/
// Each Hi Interrupt need write to this register for synchroning start of hardware procedures

#define flx_tmexp_synch flash_offset + 0x02	// _short // write only


/*----- ALTERA Passive Serial Configuration Interface for added Boards ----------------*/

// Control register
// This register have tristate outputs, control signal is OE_GENERAL
#define flx_conf_contr flash_offset + 0x03 	// _short read/write

//                      	'DSP CORE'	    'APPL. BOARD'
// 0 -- FDCLK,		recognize -- J2/A13     J9/8; J10/6
// 1 -- FDATA,		recognize -- J2/B44     J9/6; J10/4
// 2 -- FCONFIG,recognize -- J2/B54     J9/4; J10/2
// 3 -- FnCE,   recognize -- J2/A22     J9/7; J10/2
// 4..15 -- nc

// Status register
#define flx_conf_status flash_offset + 0x04 	// _short read only

//                      	       'DSP CORE'	    'APPL. BOARD'
// 0..9 -- nc
// 10 -- FnSTATUS,		    recognize -- J2/A66     J9/5; J10/3
// 11 -- FCONF_DONE,		  recognize -- J2/A21     J9/2; J10/1
// 12..15 -- nc

/*---- Daisy-Chain Output Registers --------------------------------------------------*/
// This register have tristate outputs, control signal is OE_GENERAL

#define flx_dc_out flash_offset + 0x0f 	// _short read/write

//                      	'DSP CORE'	    'APPL. BOARD'
// 0 -- IO_1,   recognize -- J2/A59     J9/24; J10/22
// 1 -- IO_2,   recognize -- J1/A47     J9/26; J10/24
// 2 -- IO_3,   recognize -- J2/B31     J9/28; J10/26
// 3 -- IO_4,   recognize -- J2/B51     J9/21; J10/19
// 4 -- IO_5,   recognize -- J2/B12     J9/23; J10/21
// 5 -- IO_6,   recognize -- J2/A27     J9/25; J10/23
// 6 -- IO_7,   recognize -- J2/B14     J9/27; J10/25
// 7..15 -- nc

/*---- Motor Control Registers -------------------------------------------------------*/

#define flx_motor_control flash_offset + 0x0d	// _short read/write
// This register have tristate outputs, control signal is OE_GENERAL
// Set motor disable in the INI.H procedure
// 
//	'1' -- motor disable
//	'0' -- motor enable

//                      	'DSP CORE'	    'APPL. BOARD'
// 0 -- EN1,		recognize -- J2/B49       	Motor-1(U31,U33)
// 1 -- EN2,		recognize -- J2/B48       	Motor-2(U32,U34)
// 2 -- EN3,		recognize -- J2/A41       	Motor-3(U36,U38)
// 3 -- EN4,		recognize -- J2/A1        	Motor-4(U37,U39)
// 4 -- EN5,		recognize -- J2/B34       	Motor-5(U41,U43)
// 5 -- EN6,		recognize -- J2/A67       	Motor-6(U42,U44)
// 6 -- EN7,		recognize -- J2/B67       	Motor-7(U45,U47)
// 7 -- EN8,		recognize -- J1/A58       	Motor-8(U46,U48)
// 8..15 -- nc

/*---- Motor Status Registers -------------------------------------------------------*/

#define flx_motor_status flash_offset + 0x0e	// _short read only

// Thermal Shut Down Input of the power drivers
// Activ if Tj>160 gradus C
// '0' -- normal
// '1' -- Shut Down Driver
// These ssignals are testing when ENx=0 only (driver enable).

//                      	'DSP CORE'	    'APPL. BOARD'
// 0 -- SD1,		recognize -- J2/B60       	Motor-1(U31,U33)
// 1 -- SD2,		recognize -- J2/A10       	Motor-2(U32,U34)
// 2 -- SD3,		recognize -- J2/B23       	Motor-3(U36,U38)
// 3 -- SD4,		recognize -- J2/A53       	Motor-4(U37,U39)
// 4 -- SD5,		recognize -- J2/B13       	Motor-5(U41,U43)
// 5 -- SD6,		recognize -- J2/B4        	Motor-6(U42,U44)
// 6 -- SD7,		recognize -- J2/B11       	Motor-6(U45,U47)
// 7 -- SD8,		recognize -- J2/B68       	Motor-8(U46,U48)
// 8..15 -- nc


/*---- General Output Register -------------------------------------------------------*/

#define flx_out flash_offset + 0x10	// _short read/write
// The flx_out have tristate outputs, control signal is OE_GENERAL
// for OUTx signals:
//	'1' -- is not activ (OFF)
//	'0' -- is activ (ON)

//                      	'DSP CORE'	    'APPL. BOARD'
// 0 -- OUT1,   recognize -- J2/B42     J14/1,2         'State Led'
// 1 -- OUT2,   recognize -- J2/A15     J14/3,4
// 2 -- OUT3,   recognize -- J2/B30     J14/5,6
// 3 -- OUT4,   recognize -- J2/B7      J14/7,8
// 4 -- OUT5,   recognize -- J2/B5      J14/9,10        NA
// 5 -- OUT6,   recognize -- J2/B38     J14/11,12       NA
// 6 -- OUT7,   recognize -- J2/B27     J14/13,14       NA
// 7..15 -- nc

/*---- General Input Register -------------------------------------------------------*/

#define flx_in flash_offset + 0x11	// _short read only
//	'1' -- is not activ (OFF)
//	'0' -- is activ (ON)

//                      	'DSP CORE'	    'APPL. BOARD'
// 0 -- IN1,   recognize -- J2/B55     J15/1,2           NA
// 1 -- IN2,   recognize -- J2/A31     J15/3,4           NA
// 2 -- IN3,   recognize -- J2/A3      J15/5,6           NA
// 3 -- IN4,   recognize -- J2/B57     J15/7,8           NA
// 4 -- IN5,   recognize -- J2/A61     J15/9,10          NA
// 5 -- IN6,   recognize -- J2/B47     J15/11,12         NA
// 6 -- IN7,   recognize -- J2/A64     J15/13,14         NA
// 7 -- IN8,   recognize -- J2/B59     J15/15,16         NA
// 8 -- IN9,   recognize -- J2/A24     J15/17,18         NA
// 9 -- IN10,  recognize -- J2/A5      J15/19,20         NA
// 10-- IN11,  recognize -- J2/B45     J15/21,22         NA
// 11-- IN12,  recognize -- J2/A19     J15/23,24         NA
// 12-- IN13,  recognize -- J2/A14     J15/25,26         NA
// 13-- IN14,  recognize -- J1/A51     J15/27,28         NA
// 14-- IN15,  recognize -- J2/A44     J15/29,30         NA
// 15-- IN16,  recognize -- J2/A40     J15/31,32         NA


/*--------- Motor Current Measurement Function ----------------------------*/
// all registers is 13bit (12...0), circul counter
// Meas. Frequncy is 80MHz
// There is PWM_SINCH signal for triangle signal generator
//   PWM_SINCH is the 20kHz, Duty Cicle 50%, Recognize -- J2/A52

//              			         'DSP CORE' 'APLICATION BOARD'

#define flx_curr1 flash_offset + 0x05          // _short read only
//	PWM_I1,     recognize -- J2/B36     J6/24 (M1-C)

#define flx_curr2 flash_offset + 0x06          // _short
//	PWM_I2,     recognize -- J2/A29     J6/23 (M2-C)

#define flx_curr3 flash_offset + 0x07          // _short
//	PWM_I3,     recognize -- J2/B35     J6/18 (M3-C)

#define flx_curr4 flash_offset + 0x08          // _short
//	PWM_I4,     recognize -- J2/A55     J6/17 (M4-C)

#define flx_curr5 flash_offset + 0x09          // _short
//	PWM_I5,     recognize -- J2/B50     J6/12 (M5-C)

#define flx_curr6 flash_offset + 0x0a          // _short
//	PWM_I6,     recognize -- J2/B61     J6/11 (M6-C)

#define flx_curr7 flash_offset + 0x0b          // _short
//	PWM_I7,     recognize -- J2/B10     J6/6  (M7-C)

#define flx_curr8 flash_offset + 0x0c          // _short
//	PWM_I8,     recognize -- J2/A42     J6/5  (M8-C)


/*---------------- RS-485 Interface NOT Connected -------------------------------------*/
// There are two registers of the RS-485 Interface.

// Control Register - 'flx_rs485_contr':
// 0 -- RT_EN1 (direction of RT1 buffer),        recognize -- J2/B43
// 1 -- RT_EN2 (direction of RT2 buffer),        recognize -- J2/A12
// 2 -- RT_EN3 (direction of RT3 buffer),        recognize -- J1/A49
// 3 -- RT_EN4 (direction of RT4 buffer),        recognize -- J2/B32
//  '0' -- RTx buffers are receivers
//  '1' -- RTx buffers are transmiters

#define flx_rs485_contr flash_offset + 0x16          // _short write/read

// Data register - 'flx_rs485_data':
// Bits data register are outputs or inputs in accordence with 
// bits function of the control register. 
// 0 -- RT1,        recognize -- J2/B39         J11/1,2
// 1 -- RT2,        recognize -- J2/A39         J11/3,4
// 2 -- RT3,        recognize -- J2/B37         J11/5,6
// 3 -- RT4,        recognize -- J2/B58         J11/7,8

#define flx_rs485_data flash_offset + 0x16          // _short write/read         

/*---------------- D/A Convertor ----------------------------------------*/
// Design for 2 D/A (8bit resolution) Convertors (LTC1665) with siral interface 
// This is writable registers only
// Analog Output Chanals da_m.. -- most byte, da_l.. -- last byte
//
// da_l.. register Data Format:
//
// 0 -- don't care
// 1 -- don't care
// 2 -- don't care
// 3 -- don't care
// 4 -- data D0
// 5 -- data D1
// 6 -- data D2
// 7 -- data D3

// da_m.. register Data Format:
//
// 0 -- data D4
// 1 -- data D5
// 2 -- data D6
// 3 -- data D7
// 4 -- address A0
// 5 -- address A1
// 6 -- address A2
// 7 -- address A3
//

//---- MOTOR 1
#define flx_dam_cos1 flash_offset + 0x200 // _short A[3..0] = 0x1
#define flx_dal_cos1 flash_offset + 0x201	// _short 
// M1-B,		recognize -- J6/22

#define flx_dam_sin1 flash_offset + 0x202 // _short A[3..0] = 0x1
#define flx_dal_sin1 flash_offset + 0x203	// _short
// M1-A,		recognize -- J6/20

//---- MOTOR 2
#define flx_dam_cos2 flash_offset + 0x204 // _short A[3..0] = 0x2
#define flx_dal_cos2 flash_offset + 0x205	// _short 
// M2-B,		recognize -- J6/21

#define flx_dam_sin2 flash_offset + 0x206 // _short A[3..0] = 0x2
#define flx_dal_sin2 flash_offset + 0x207	// _short
// M2-A,		recognize -- J6/19

//---- MOTOR 3
#define flx_dam_cos3 flash_offset + 0x208 // _short A[3..0] = 0x3
#define flx_dal_cos3 flash_offset + 0x209	// _short 
// M3-B,		recognize -- J6/16

#define flx_dam_sin3 flash_offset + 0x20a // _short A[3..0] = 0x3
#define flx_dal_sin3 flash_offset + 0x20b	// _short
// M3-A,		recognize -- J6/14

//---- MOTOR 4
#define flx_dam_cos4 flash_offset + 0x20c // _short A[3..0] = 0x4
#define flx_dal_cos4 flash_offset + 0x20d	// _short 
// M4-B,		recognize -- J6/15

#define flx_dam_sin4 flash_offset + 0x20e // _short A[3..0] = 0x4
#define flx_dal_sin4 flash_offset + 0x20f	// _short
// M4-A,		recognize -- J6/13

//---- MOTOR 8
#define flx_dam_cos8 flash_offset + 0x210 // _short A[3..0] = 0x5
#define flx_dal_cos8 flash_offset + 0x211	// _short 
// M8-B,		recognize -- J6/3

#define flx_dam_sin8 flash_offset + 0x212 // _short A[3..0] = 0x5
#define flx_dal_sin8 flash_offset + 0x213	// _short
// M8-A,		recognize -- J6/1

//---- MOTOR 7
#define flx_dam_cos7 flash_offset + 0x214 // _short A[3..0] = 0x6
#define flx_dal_cos7 flash_offset + 0x215	// _short 
// M7-B,		recognize -- J6/4

#define flx_dam_sin7 flash_offset + 0x216 // _short A[3..0] = 0x6
#define flx_dal_sin7 flash_offset + 0x217	// _short
// M7-A,		recognize -- J6/2

//---- MOTOR 6
#define flx_dam_cos6 flash_offset + 0x218 // _short A[3..0] = 0x7
#define flx_dal_cos6 flash_offset + 0x219	// _short 
// M6-B,		recognize -- J6/9

#define flx_dam_sin6 flash_offset + 0x21a // _short A[3..0] = 0x7
#define flx_dal_sin6 flash_offset + 0x21b	// _short
// M6-A,		recognize -- J6/7

//---- MOTOR 5
#define flx_dam_cos5 flash_offset + 0x21c // _short A[3..0] = 0x8
#define flx_dal_cos5 flash_offset + 0x21d	// _short 
// M5-B,		recognize -- J6/10

#define flx_dam_sin5 flash_offset + 0x21e // _short A[3..0] = 0x8
#define flx_dal_sin5 flash_offset + 0x21f	// _short
// M5-A,		recognize -- J6/8


/*------- Reset WatchDog Registyer --------------------------------------*/
// any read or write command and any data format
// The Period of execute command must be less 1.6 sec.

#define flx_wd flash_offset + 0x1800ff	// _short
